@@ -573,6 +573,70 @@ function testGError() {
     }
 }
 
+function testGErrorMessages() {
+    GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+                             'JS ERROR: Gio.IOErrorEnum: *');
+    try {
+	let file = Gio.file_new_for_path("\\/,.^!@&$_don't exist");
+        file.read(null);
+    } catch(e) {
+	logError(e);
+    }
+
+    GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+			     'JS ERROR: Gio.IOErrorEnum: a message\ntestGErrorMessages@*');
+    try {
+	throw new Gio.IOErrorEnum({ message: 'a message', code: 0 });
+    } catch(e) {
+	logError(e);
+    }
+
+    GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+			     'JS ERROR: Gio.IOErrorEnum: a message\ntestGErrorMessages@*');
+    logError(new Gio.IOErrorEnum({ message: 'a message', code: 0 }));
+
+    // No stack for GLib.Error constructor
+    GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+			     'JS ERROR: Gio.IOErrorEnum: a message');
+    logError(new GLib.Error(Gio.IOErrorEnum, 0, 'a message'));
+
+    GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+			     'JS ERROR: GLib.Error my-error: a message');
+    logError(new GLib.Error(GLib.quark_from_string('my-error'), 0, 'a message'));
+
+    // Now with prefix
+
+    GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+                             'JS ERROR: prefix: Gio.IOErrorEnum: *');
+    try {
+	let file = Gio.file_new_for_path("\\/,.^!@&$_don't exist");
+        file.read(null);
+    } catch(e) {
+	logError(e, 'prefix');
+    }
+
+    GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+			     'JS ERROR: prefix: Gio.IOErrorEnum: a message\ntestGErrorMessages@*');
+    try {
+	throw new Gio.IOErrorEnum({ message: 'a message', code: 0 });
+    } catch(e) {
+	logError(e, 'prefix');
+    }
+
+    GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+			     'JS ERROR: prefix: Gio.IOErrorEnum: a message\ntestGErrorMessages@*');
+    logError(new Gio.IOErrorEnum({ message: 'a message', code: 0 }), 'prefix');
+
+    // No stack for GLib.Error constructor
+    GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+			     'JS ERROR: prefix: Gio.IOErrorEnum: a message');
+    logError(new GLib.Error(Gio.IOErrorEnum, 0, 'a message'), 'prefix');
+
+    GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+			     'JS ERROR: prefix: GLib.Error my-error: a message');
+    logError(new GLib.Error(GLib.quark_from_string('my-error'), 0, 'a message'), 'prefix');
+}
+
 function testWrongClassGObject() {
     /* Function calls */
     // Everything.func_obj_null_in expects a Everything.TestObj
