@@ -8,79 +8,81 @@ const Mainloop = imports.mainloop;
  *
  * *** NOTE: If you add stuff here, you need to update testIntrospectReal
  */
-var TestIface = <interface name="org.gnome.gjs.Test">
-<method name="nonJsonFrobateStuff">
-    <arg type="i" direction="in"/>
-    <arg type="s" direction="out"/>
-</method>
-<method name="frobateStuff">
-    <arg type="a{sv}" direction="in"/>
-    <arg type="a{sv}" direction="out"/>
-</method>
-<method name="alwaysThrowException">
-    <arg type="a{sv}" direction="in"/>
-    <arg type="a{sv}" direction="out"/>
-</method>
-<method name="thisDoesNotExist"/>
-<method name="noInParameter">
-    <arg type="s" direction="out"/>
-</method>
-<method name="multipleInArgs">
-    <arg type="i" direction="in"/>
-    <arg type="i" direction="in"/>
-    <arg type="i" direction="in"/>
-    <arg type="i" direction="in"/>
-    <arg type="i" direction="in"/>
-    <arg type="s" direction="out"/>
-</method>
-<method name="noReturnValue"/>
-<method name="emitSignal"/>
-<method name="multipleOutValues">
-    <arg type="s" direction="out"/>
-    <arg type="s" direction="out"/>
-    <arg type="s" direction="out"/>
-</method>
-<method name="oneArrayOut">
-    <arg type="as" direction="out"/>
-</method>
-<method name="arrayOfArrayOut">
-    <arg type="aas" direction="out"/>
-</method>
-<method name="multipleArrayOut">
-    <arg type="as" direction="out"/>
-    <arg type="as" direction="out"/>
-</method>
-<method name="arrayOutBadSig">
-    <arg type="i" direction="out"/>
-</method>
-<method name="byteArrayEcho">
-    <arg type="ay" direction="in"/>
-    <arg type="ay" direction="out"/>
-</method>
-<method name="byteEcho">
-    <arg type="y" direction="in"/>
-    <arg type="y" direction="out"/>
-</method>
-<method name="dictEcho">
-    <arg type="a{sv}" direction="in"/>
-    <arg type="a{sv}" direction="out"/>
-</method>
-<method name="echo">
-    <arg type="s" direction="in"/>
-    <arg type="i" direction="in"/>
-    <arg type="s" direction="out"/>
-    <arg type="i" direction="out"/>
-</method>
-<method name="structArray">
-    <arg type="a(ii)" direction="out"/>
-</method>
-<signal name="signalFoo">
-    <arg type="s" direction="out"/>
-</signal>
-<property name="PropReadOnly" type="b" access="read" />
-<property name="PropWriteOnly" type="s" access="write" />
-<property name="PropReadWrite" type="v" access="readwrite" />
-</interface>
+var TestIface = '<node> \
+<interface name="org.gnome.gjs.Test"> \
+<method name="nonJsonFrobateStuff"> \
+    <arg type="i" direction="in"/> \
+    <arg type="s" direction="out"/> \
+</method> \
+<method name="frobateStuff"> \
+    <arg type="a{sv}" direction="in"/> \
+    <arg type="a{sv}" direction="out"/> \
+</method> \
+<method name="alwaysThrowException"> \
+    <arg type="a{sv}" direction="in"/> \
+    <arg type="a{sv}" direction="out"/> \
+</method> \
+<method name="thisDoesNotExist"/> \
+<method name="noInParameter"> \
+    <arg type="s" direction="out"/> \
+</method> \
+<method name="multipleInArgs"> \
+    <arg type="i" direction="in"/> \
+    <arg type="i" direction="in"/> \
+    <arg type="i" direction="in"/> \
+    <arg type="i" direction="in"/> \
+    <arg type="i" direction="in"/> \
+    <arg type="s" direction="out"/> \
+</method> \
+<method name="noReturnValue"/> \
+<method name="emitSignal"/> \
+<method name="multipleOutValues"> \
+    <arg type="s" direction="out"/> \
+    <arg type="s" direction="out"/> \
+    <arg type="s" direction="out"/> \
+</method> \
+<method name="oneArrayOut"> \
+    <arg type="as" direction="out"/> \
+</method> \
+<method name="arrayOfArrayOut"> \
+    <arg type="aas" direction="out"/> \
+</method> \
+<method name="multipleArrayOut"> \
+    <arg type="as" direction="out"/> \
+    <arg type="as" direction="out"/> \
+</method> \
+<method name="arrayOutBadSig"> \
+    <arg type="i" direction="out"/> \
+</method> \
+<method name="byteArrayEcho"> \
+    <arg type="ay" direction="in"/> \
+    <arg type="ay" direction="out"/> \
+</method> \
+<method name="byteEcho"> \
+    <arg type="y" direction="in"/> \
+    <arg type="y" direction="out"/> \
+</method> \
+<method name="dictEcho"> \
+    <arg type="a{sv}" direction="in"/> \
+    <arg type="a{sv}" direction="out"/> \
+</method> \
+<method name="echo"> \
+    <arg type="s" direction="in"/> \
+    <arg type="i" direction="in"/> \
+    <arg type="s" direction="out"/> \
+    <arg type="i" direction="out"/> \
+</method> \
+<method name="structArray"> \
+    <arg type="a(ii)" direction="out"/> \
+</method> \
+<signal name="signalFoo"> \
+    <arg type="s" direction="out"/> \
+</signal> \
+<property name="PropReadOnly" type="b" access="read" /> \
+<property name="PropWriteOnly" type="s" access="write" /> \
+<property name="PropReadWrite" type="v" access="readwrite" /> \
+</interface> \
+</node>';
 
 /* Test is the actual object exporting the dbus methods */
 function Test() {
@@ -264,6 +266,9 @@ function testFrobateStuff() {
 /* excp must be exactly the exception thrown by the remote method
    (more or less) */
 function testThrowException() {
+    GLib.test_expect_message('Gjs', GLib.LogLevelFlags.LEVEL_WARNING,
+                             'JS ERROR: Exception in method call: alwaysThrowException: *');
+
     let theResult, theExcp;
     proxy.alwaysThrowExceptionRemote({}, function(result, excp) {
         theResult = result;
