@@ -51,24 +51,31 @@ const GObjectMeta = new Lang.Class({
             }
         }
 
-        for (let prop in params) {
-            let value = this.prototype[prop];
-            if (typeof value === 'function') {
-                if (prop.slice(0, 6) == 'vfunc_') {
-                    Gi.hook_up_vfunc(this.prototype, prop.slice(6), value);
-                } else if (prop.slice(0, 3) == 'on_') {
-                    let id = GObject.signal_lookup(prop.slice(3).replace('_', '-'), this.$gtype);
+	let propertyObj = { };
+	Object.getOwnPropertyNames(params).forEach(function(name) {
+            if (name == 'Name' || name == 'Extends' || name == 'Abstract')
+		return;
+
+            let descriptor = Object.getOwnPropertyDescriptor(params, name);
+
+            if (typeof descriptor.value === 'function') {
+		let wrapped = this.prototype[name];
+
+                if (name.slice(0, 6) == 'vfunc_') {
+                    Gi.hook_up_vfunc(this.prototype, name.slice(6), wrapped);
+                } else if (name.slice(0, 3) == 'on_') {
+                    let id = GObject.signal_lookup(name.slice(3).replace('_', '-'), this.$gtype);
                     if (id != 0) {
                         GObject.signal_override_class_closure(id, this.$gtype, function() {
                             let argArray = Array.prototype.slice.call(arguments);
                             let emitter = argArray.shift();
 
-                            value.apply(emitter, argArray);
+                            wrapped.apply(emitter, argArray);
                         });
                     }
                 }
-            }
-        }
+	    }
+	}.bind(this));
     },
 
     _isValidClass: function(klass) {
@@ -213,13 +220,11 @@ function _init() {
     };
 
     this.ParamSpec.flags = function(name, nick, blurb, flags, flags_type, default_value) {
-        return GObject.ParamSpec._new_internal(name, GObject.TYPE_FLAGS,
-                                               nick, blurb, flags, flags_type, default_value);
+        return GObject.ParamSpec._new_internal(name, flags_type, nick, blurb, flags, default_value);
     };
 
     this.ParamSpec.enum = function(name, nick, blurb, flags, enum_type, default_value) {
-        return GObject.ParamSpec._new_internal(name, GObject.TYPE_ENUM,
-                                               nick, blurb, flags, enum_type, default_value);
+        return GObject.ParamSpec._new_internal(name, enum_type, nick, blurb, flags, default_value);
     };
 
     this.ParamSpec.double = function(name, nick, blurb, flags, minimum, maximum, default_value) {
@@ -232,6 +237,18 @@ function _init() {
                                                nick, blurb, flags, default_value);
     };
 
+    this.ParamSpec.boxed = function(name, nick, blurb, flags, boxed_type) {
+	return GObject.ParamSpec._new_internal(name, boxed_type, nick, blurb, flags);
+    };
+
+    this.ParamSpec.object = function(name, nick, blurb, flags, object_type) {
+	return GObject.ParamSpec._new_internal(name, object_type, nick, blurb, flags);
+    };
+
+    this.ParamSpec.param = function(name, nick, blurb, flags, param_type) {
+	return GObject.ParamSpec._new_internal(name, boxed_type, nick, blurb, flags);
+    };
+
     this.Class = GObjectMeta;
     this.Object.prototype.__metaclass__ = this.Class;
 
