@@ -79,12 +79,16 @@ function _proxyInvoker(methodName, sync, inSignature, arg_array) {
     var inVariant = new GLib.Variant('(' + inSignature.join('') + ')', arg_array);
 
     var asyncCallback = function (proxy, result) {
+        var outVariant = null, succeeded = false;
         try {
-            var outVariant = proxy.call_finish(result);
-            replyFunc(outVariant.deep_unpack(), null);
+            outVariant = proxy.call_finish(result);
+            succeeded = true;
         } catch (e) {
             replyFunc(null, e);
         }
+
+        if (succeeded)
+            replyFunc(outVariant.deep_unpack(), null);
     };
 
     if (sync) {
@@ -218,23 +222,7 @@ function _newNodeInfo(constructor, value) {
 }
 
 function _newInterfaceInfo(value) {
-    var xml;
-    if (typeof value == 'string')
-        xml = new XML(value);
-    else if (value instanceof XML)
-        xml = value;
-    else
-        throw TypeError('Invalid type ' + Object.prototype.toString.call(value));
-
-    var node;
-    if (xml.name() == 'interface') {
-        // wrap inside a node
-        node = <node/>;
-        node.node += xml;
-    } else
-        node = xml;
-
-    var nodeInfo = Gio.DBusNodeInfo.new_for_xml(node);
+    var nodeInfo = Gio.DBusNodeInfo.new_for_xml(value);
     return nodeInfo.interfaces[0];
 }
 
@@ -280,6 +268,7 @@ function _handleMethodCall(info, impl, method_name, parameters, invocation) {
                     // likely to be a normal JS error
                     name = 'org.gnome.gjs.JSError.' + name;
                 }
+                logError(e, "Exception in method call: " + method_name);
                 invocation.return_dbus_error(name, e.message);
             }
             return;
